@@ -1,5 +1,6 @@
-from ..const import EventType, TaskType
-from pydantic import BaseModel, Field, field_validator
+from typing import Any
+from ..const import EventType, TaskStatus, TaskType
+from pydantic import BaseModel, ConfigDict, Field, field_validator
 from uuid import UUID
 import json
 
@@ -8,7 +9,7 @@ class GetTraceEventsReq(BaseModel):
     trace_id: UUID = Field(
         ...,
         description="Unique identifier for the entire trace",
-        json_schema_extra={"example": UUID("75430787-c19a-4f90-8c1f-07d215a664b7")},
+        json_schema_extra={"example": "75430787-c19a-4f90-8c1f-07d215a664b7"},
     )
 
     last_event_id: str = Field(
@@ -29,6 +30,8 @@ class GetTraceEventsReq(BaseModel):
 class AlgorithmItem(BaseModel):
     """Algorithm item model"""
 
+    model_config = ConfigDict(extra="ignore", validate_by_name=True)
+
     name: str = Field(..., description="Algorithm name")
     image: str = Field(..., description="Algorithm image")
     tag: str = Field(..., description="Algorithm image tag")
@@ -37,20 +40,24 @@ class AlgorithmItem(BaseModel):
 class DatasetOptions(BaseModel):
     """Dataset options model"""
 
+    model_config = ConfigDict(extra="ignore", validate_by_name=True)
+
     dataset: str = Field(..., description="Dataset name")
 
 
 class DetectorRecord(BaseModel):
     """Detector record model"""
 
-    span_name: str = Field(alias="SpanName", description="Span name")
-    issues: dict[str, any] = Field(default_factory=dict, description="Issues detected")
-    abnormal_avg_duration: float = Field(alias="AbnormalAvgDuration")
-    normal_avg_duration: float = Field(alias="NormalAvgDuration")
-    abnormal_succ_rate: float = Field(alias="AbnormalSuccRate")
-    normal_succ_rate: float = Field(alias="NormalSuccRate")
-    abnormal_p99: float = Field(alias="AbnormalP99")
-    normal_p99: float = Field(alias="NormalP99")
+    model_config = ConfigDict(extra="ignore", validate_by_name=True)
+
+    span_name: str = Field(..., alias="SpanName", description="Span name")
+    issues: dict[str, Any] = Field(..., description="Issues detected")
+    abnormal_avg_duration: float = Field(..., alias="AbnormalAvgDuration")
+    normal_avg_duration: float = Field(..., alias="NormalAvgDuration")
+    abnormal_succ_rate: float = Field(..., alias="AbnormalSuccRate")
+    normal_succ_rate: float = Field(..., alias="NormalSuccRate")
+    abnormal_p99: float = Field(..., alias="AbnormalP99")
+    normal_p99: float = Field(..., alias="NormalP99")
 
     @field_validator("issues", mode="before")
     def parse_issues(cls, v):
@@ -62,40 +69,50 @@ class DetectorRecord(BaseModel):
 
         return v if isinstance(v, dict) else {}
 
-    class Config:
-        extra = "ignore"
-        allow_population_by_field_name = True
-
 
 class ExecutionOptions(BaseModel):
     """Execution options model"""
 
-    algorithm: str = Field(..., description="Algorithm name")
-    dataset: str = Field(..., description="Dataset name")
-    execution_id: int = Field(..., description="Execution ID", ge=1)
+    model_config = ConfigDict(extra="ignore", validate_by_name=True)
+
+    algorithm: AlgorithmItem = Field(..., description="Algorithm item")
+    dataset: str = Field(..., description="dataset")
+    execution_id: int = Field(..., description="Execution ID")
+
+
+class InfoPayload(BaseModel):
+    """Info payload model"""
+
+    model_config = ConfigDict(extra="ignore", validate_by_name=True)
+
+    status: TaskStatus = Field(..., description="Status of the task")
+    message: str = Field(
+        ..., alias="msg", description="Message associated with the task status"
+    )
 
 
 class StreamEvent(BaseModel):
     """
-    StreamEvent 事件流数据模型
+    StreamEvent data model for the event stream.
 
     Attributes:
-        task_id (UUID): 任务的唯一标识符，用于关联特定任务实例
-            例如: "005f94a9-f9a2-4e50-ad89-61e05c1c15a0"
+        task_id (UUID): A unique identifier for the task, used to associate with a specific task instance.
+            Example: "005f94a9-f9a2-4e50-ad89-61e05c1c15a0"
 
-        task_type (TaskType): 任务类型枚举值，指明事件相关的任务类别
-            可选值:
-            - BuildDataset: 构建数据集任务
-            - CollectResult: 收集结果任务
-            - FaultInjection: 故障注入任务
-            - RestartService: 服务重启任务
-            - RunAlgorithm: 运行算法任务
+        task_type (TaskType): An enum value indicating the category of the task associated with the event.
+            Possible values:
+            - BuildDataset: Task for building a dataset.
+            - BuildImage: Task for building a Docker image.
+            - CollectResult: Task for collecting results.
+            - FaultInjection: Task for fault injection.
+            - RestartService: Task for restarting a service.
+            - RunAlgorithm: Task for running an algorithm.
 
-        event_name (EventType): 事件类型枚举值，表示事件的性质或操作类型
+        event_name (EventType): An enum value indicating the nature or type of the operation or status change.
 
-        payload (Any, 可选): 事件相关的附加数据，内容根据事件类型不同而变化
-            - 对于错误事件: 包含错误详情和堆栈信息
-            - 对于完成事件: 可能包含执行结果数据
+        payload (Any, optional): Additional data associated with the event. The content varies depending on the event type.
+            - For error events: Contains error details and stack trace information.
+            - For completion events: May contain execution result data.
     """
 
     task_id: UUID = Field(
@@ -116,7 +133,7 @@ class StreamEvent(BaseModel):
         json_schema_extra={"example": ["task.start"]},
     )
 
-    payload: any | None = Field(
+    payload: Any | None = Field(
         None,
         description="Additional data associated with the event. Content varies based on event_name",
     )
